@@ -38,6 +38,7 @@ plot_tb_burden_overview <- function(df = NULL, dict = NULL,
                                     metric = "e_inc_100k",
                                     metric_label = NULL,
                                     countries = NULL,
+                                    years = NULL,
                                     compare_to_region = FALSE,
                                     facet = NULL, annual_change = FALSE,
                                     trans = "identity",
@@ -58,6 +59,7 @@ plot_tb_burden_overview <- function(df = NULL, dict = NULL,
                              metric = metric,
                              metric_label = metric_label,
                              countries = countries,
+                             years = years,
                              compare_to_region = compare_to_region,
                              facet = facet,
                              annual_change = annual_change,
